# bigmcl

High throughput large scale Markov clustering (MCL) via subgraph extraction    
bigmcl will isolate disconnected subgraphs from a large graph file and perform
Markov clustering on the subgraphs. bigmcl enables MCL on large, highly 
disconnected graphs, such as those used in orthogroup inference.

## INSTALL

```
pip install bigmcl
```

Download `mcl` and add to your path.
